==> haskell-fourmolu-0.11.0.0-61-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-fourmolu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fourmolu
version:              0.11.0.0
visibility:           public
id:                   fourmolu-0.11.0.0-9Zmqz6cZRggIU2jCc7lLMH
key:                  fourmolu-0.11.0.0-9Zmqz6cZRggIU2jCc7lLMH
license:              BSD-3-Clause
maintainer:
    Matt Parsons <parsonsmatt@gmail.com>
    George Thomas <georgefsthomas@gmail.com>
    Brandon Chinn <brandonchinn178@gmail.com>

homepage:             https://github.com/fourmolu/fourmolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  60bed1ccc025da51fe4442e6b9a65fcc
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff.ParseResult Ormolu.Diff.Text
    Ormolu.Exception Ormolu.Fixity Ormolu.Fixity.Internal
    Ormolu.Fixity.Parser Ormolu.Fixity.Printer Ormolu.Imports
    Ormolu.Parser Ormolu.Parser.CommentStream Ormolu.Parser.Pragma
    Ormolu.Parser.Result Ormolu.Printer Ormolu.Printer.Combinators
    Ormolu.Printer.Comments Ormolu.Printer.Internal
    Ormolu.Printer.Meat.Common Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.OpTree
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Preprocess Ormolu.Terminal Ormolu.Utils
    Ormolu.Utils.Cabal Ormolu.Utils.Fixity Ormolu.Utils.IO

hidden-modules:       Ormolu.Config.Gen GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fourmolu-0.11.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fourmolu-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fourmolu-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fourmolu
hs-libraries:         HSfourmolu-0.11.0.0-9Zmqz6cZRggIU2jCc7lLMH
depends:
    Cabal-syntax-3.8.1.0 Diff-0.5-2Up5HNAxZSNmr3b9Y21Rq
    MemoTrie-0.6.11-6zHgK2beIGoHVVIrPphHAJ
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    ansi-terminal-1.0.2-K3FcB9OuSW9G9IWrQwwwo4 array-0.5.4.0
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 dlist-1.0-E99MqJW5mmB4kr4PCgIESI
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    megaparsec-9.7.0-8vxoLKsvFvg2EeYv7J5Buq mtl-2.2.2
    syb-0.7.3-Lap6GPARkRXCVbqA2faY6P text-2.0.2
    yaml-0.11.11.2-AOYlSEsKg9dHqSBpc42qFm

haddock-interfaces:   /usr/share/doc/haskell-fourmolu/html/fourmolu.haddock
haddock-html:         /usr/share/doc/haskell-fourmolu/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fourmolu-0.11.0.0-80-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-fourmolu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fourmolu
version:              0.11.0.0
visibility:           public
id:                   fourmolu-0.11.0.0-L1Ht0IARavLFgGTtxrz3lI
key:                  fourmolu-0.11.0.0-L1Ht0IARavLFgGTtxrz3lI
license:              BSD-3-Clause
maintainer:
    Matt Parsons <parsonsmatt@gmail.com>
    George Thomas <georgefsthomas@gmail.com>
    Brandon Chinn <brandonchinn178@gmail.com>

homepage:             https://github.com/fourmolu/fourmolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  b6c8b73aafe31ccd63b7f3653c035e09
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff.ParseResult Ormolu.Diff.Text
    Ormolu.Exception Ormolu.Fixity Ormolu.Fixity.Internal
    Ormolu.Fixity.Parser Ormolu.Fixity.Printer Ormolu.Imports
    Ormolu.Parser Ormolu.Parser.CommentStream Ormolu.Parser.Pragma
    Ormolu.Parser.Result Ormolu.Printer Ormolu.Printer.Combinators
    Ormolu.Printer.Comments Ormolu.Printer.Internal
    Ormolu.Printer.Meat.Common Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.OpTree
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Preprocess Ormolu.Terminal Ormolu.Utils
    Ormolu.Utils.Cabal Ormolu.Utils.Fixity Ormolu.Utils.IO

hidden-modules:       Ormolu.Config.Gen GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fourmolu-0.11.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fourmolu-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fourmolu-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fourmolu
hs-libraries:         HSfourmolu-0.11.0.0-L1Ht0IARavLFgGTtxrz3lI
depends:
    Cabal-syntax-3.8.1.0 Diff-0.5-2tX1FyxWy6p7M2fvM0xekx
    MemoTrie-0.6.11-2FivWXzu1Qe4XIyz5xz0Nj
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    ansi-terminal-1.0.2-HSq0v3QUl8T11Wgx1QLnTe array-0.5.4.0
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 dlist-1.0-DlYyWPxbaG7vpSilKIFCh
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    megaparsec-9.7.0-A5HZG6HxQB028mYZSYROei mtl-2.2.2
    syb-0.7.3-C5AaeelSWDKGvBUWTjIxkt text-2.0.2
    yaml-0.11.11.2-AINh0PDgMr7KUeC4aAoheB

haddock-interfaces:   /usr/share/doc/haskell-fourmolu/html/fourmolu.haddock
haddock-html:         /usr/share/doc/haskell-fourmolu/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
